@@ -1,9 +1,9 @@
 #' Creates an R expression for a linear predictor from a data frame of terms and
 #' coefficients
-#' @param x An object that uses a [glmnet::glmnet()] model and all numeric predictors. 
-#' @param ... Not currently used. 
+#' @param x An object that uses a [glmnet::glmnet()] model and all numeric predictors.
+#' @param ... Not currently used.
 #' @return An R expression or a list of R expressions, depending on the type of
-#' model being used. 
+#' model being used.
 #' @export
 #' @keywords internal
 build_linear_predictor <- function(x, ...) {
@@ -12,10 +12,14 @@ build_linear_predictor <- function(x, ...) {
 
 #' @import rlang
 
-# `x` should be a tidy-type format for the data with columns terms and estimate. 
+# `x` should be a tidy-type format for the data with columns terms and estimate.
 build_linear_predictor_eng <- function(x, ...) {
-  slopes <- x %>% dplyr::filter(terms != "(Intercept)")
-  lin_pred <- purrr::map2(slopes$terms, slopes$estimate, ~ rlang::expr((!!sym(.x) * !!.y)))
+  slopes <- x |> dplyr::filter(terms != "(Intercept)")
+  lin_pred <- purrr::map2(
+    slopes$terms,
+    slopes$estimate,
+    function(.x, .y) rlang::expr((!!sym(.x) * !!.y))
+  )
   if (any(x$terms == "(Intercept)")) {
     beta_0 <- x$estimate[x$terms == "(Intercept)"]
     lin_pred <- c(beta_0, lin_pred)
@@ -27,8 +31,8 @@ build_linear_predictor_eng <- function(x, ...) {
 # This is used for linear and logistic regression
 build_linear_predictor_glmnet <- function(x, ...) {
   lvls <- x$lvl
-  coefs <- 
-    .get_glmn_coefs(x$fit, x$spec$args$penalty) %>% 
+  coefs <-
+    .get_glmn_coefs(x$fit, x$spec$args$penalty) |>
     dplyr::filter(estimate != 0)
   lp <- build_linear_predictor_eng(coefs)
   lp
@@ -50,10 +54,10 @@ build_linear_predictor._lognet <- function(x, ...) {
 #' @rdname build_linear_predictor
 build_linear_predictor._multnet <- function(x, ...) {
   lvls <- x$lvl
-  coefs <- 
-    .get_glmn_coefs(x$fit, x$spec$args$penalty) %>% 
-    dplyr::filter(estimate != 0) %>% 
-    dplyr::group_nest(class, .key = "coefs") %>% 
+  coefs <-
+    .get_glmn_coefs(x$fit, x$spec$args$penalty) |>
+    dplyr::filter(estimate != 0) |>
+    dplyr::group_nest(class, .key = "coefs") |>
     dplyr::mutate(lp = purrr::map(coefs, build_linear_predictor_eng))
   coefs
 }
@@ -61,10 +65,10 @@ build_linear_predictor._multnet <- function(x, ...) {
 ## -----------------------------------------------------------------------------
 
 #' Convert one or more linear predictor to a format used for prediction
-#' 
+#'
 #' @inheritParams build_linear_predictor
-#' @param type The prediction type. 
-#' @return The return type varies, based on the model and prediction type. 
+#' @param type The prediction type.
+#' @return The return type varies, based on the model and prediction type.
 #' @export
 #' @keywords internal
 prediction_eqn <- function(x, ...) {
@@ -83,21 +87,23 @@ prediction_eqn._lognet <- function(x, type = "class", ...) {
   type <- match.arg(type, c("class", "prob"))
   model_class <- class(x$fit)[1]
   lp <- build_linear_predictor(x)
-  
+
   # glmnet models the probability of the _second_ class
   lvls <- x$lvl
-  
+
   if (type == "prob") {
     elem_names <- paste0(".pred_", lvls)
     res <- vector(mode = "list", length = 2)
     names(res) <- elem_names
-    res[[ elem_names[2] ]] <- rlang::expr(stats::binomial()$linkinv(!!lp))
-    res[[ elem_names[1] ]] <- rlang::expr(stats::binomial()$linkinv(-(!!lp)))
+    res[[elem_names[2]]] <- rlang::expr(stats::binomial()$linkinv(!!lp))
+    res[[elem_names[1]]] <- rlang::expr(stats::binomial()$linkinv(-(!!lp)))
   } else {
-    res <- 
+    res <-
       list(
-        .pred_class = 
-          rlang::expr(factor(ifelse((!!lp) > 0, !!lvls[2], !!lvls[1]), levels = !!lvls))
+        .pred_class = rlang::expr(factor(
+          ifelse((!!lp) > 0, !!lvls[2], !!lvls[1]),
+          levels = !!lvls
+        ))
       )
   }
   eqn_constuctor(res, model_class, type, lvls)
@@ -120,7 +126,7 @@ prediction_eqn._multnet <- function(x, type = "class", ...) {
   type <- match.arg(type, c("class", "prob"))
   model_class <- class(x$fit)[1]
   lvls <- x$lvl
-  res <- build_linear_predictor(x) %>% 
+  res <- build_linear_predictor(x) |>
     dplyr::mutate(.pred = purrr::map(lp, eexp))
   names(res$.pred) <- paste0(".pred_", res$class)
   eqn_constuctor(res, model_class, type, lvls)
@@ -130,10 +136,10 @@ prediction_eqn._multnet <- function(x, type = "class", ...) {
 ## -----------------------------------------------------------------------------
 
 #' Convert one or more linear predictor to a format used for prediction
-#' 
+#'
 #' @inheritParams build_linear_predictor
 #' @param x A set of model expressions generated by [prediction_eqn()].
-#' @return The return type varies, based on the model and prediction type. 
+#' @return The return type varies, based on the model and prediction type.
 #' @export
 #' @keywords internal
 stack_predict <- function(x, ...) {
@@ -160,20 +166,21 @@ stack_predict.lognet_prob <- function(x, data, ...) {
 
 
 multi_net_engine <- function(x, data, ...) {
-  res <- 
-    purrr::map_dfc(x$.pred, rlang::eval_tidy, data = data) %>%
+  res <-
+    purrr::map_dfc(x$.pred, rlang::eval_tidy, data = data) |>
     multi_net_helper()
 }
 
 multi_net_helper <- function(data, ...) {
-  data %>%
-    dplyr::rowwise() %>% 
+  data |>
+    dplyr::rowwise() |>
     dplyr::mutate(
-      .sum = sum(dplyr::c_across(dplyr::starts_with(".pred_")))) %>%
+      .sum = sum(dplyr::c_across(dplyr::starts_with(".pred_")))
+    ) |>
     dplyr::mutate(
-      dplyr::across(dplyr::starts_with(".pred_"), ~ .x/.sum),
+      dplyr::across(dplyr::starts_with(".pred_"), function(.x) .x / .sum),
       idx = which.max(dplyr::c_across(dplyr::starts_with(".pred_")))
-    ) %>% 
+    ) |>
     dplyr::ungroup()
 }
 
@@ -181,12 +188,13 @@ multi_net_helper <- function(data, ...) {
 #' @rdname stack_predict
 stack_predict.multnet_class <- function(x, data, ...) {
   lvls <- attr(x, "levels")
+  res <- multi_net_engine(x, data)
   res <- 
-    multi_net_engine(x, data) %>% 
+    res |>
     dplyr::mutate(
-      .pred_class = gsub(".pred_", "", colnames(.)[idx]),
+      .pred_class = gsub(".pred_", "", colnames(res)[idx]),
       .pred_class = factor(.pred_class, levels = lvls)
-    ) %>% 
+    ) |>
     dplyr::select(.pred_class)
   res
 }
@@ -194,7 +202,7 @@ stack_predict.multnet_class <- function(x, data, ...) {
 #' @export
 #' @rdname stack_predict
 stack_predict.multnet_prob <- function(x, data, ...) {
-  multi_net_engine(x, data) %>% 
+  multi_net_engine(x, data) |>
     dplyr::select(dplyr::starts_with(".pred_"))
 }
 
@@ -202,7 +210,7 @@ stack_predict.multnet_prob <- function(x, data, ...) {
 ## -----------------------------------------------------------------------------
 
 #' Obtain prediction equations for all possible values of type
-#' @param x A `parsnip` model with the \code{glmnet} engine. 
+#' @param x A `parsnip` model with the \code{glmnet} engine.
 #' @param ... Not used
 #' @return A named list with prediction equations for each possibel type.
 #' @export
@@ -215,7 +223,7 @@ get_expressions <- function(x, ...) {
 get_expressions._multnet <- function(x, ...) {
   list(
     class = prediction_eqn(x, type = "class"),
-    prob  = prediction_eqn(x, type = "prob")
+    prob = prediction_eqn(x, type = "prob")
   )
 }
 
@@ -224,7 +232,7 @@ get_expressions._multnet <- function(x, ...) {
 get_expressions._lognet <- function(x, ...) {
   list(
     class = prediction_eqn(x, type = "class"),
-    prob  = prediction_eqn(x, type = "prob")
+    prob = prediction_eqn(x, type = "prob")
   )
 }
 
