@@ -1,7 +1,7 @@
 #' @export
 print.data_stack <- function(x, ...) {
   mode <- attr(x, "mode")
-  
+
   if (mode == "regression") {
     n_cands <- ncol(x) - 1
     n_model_defs <- length(attr(x, "model_defs"))
@@ -9,11 +9,11 @@ print.data_stack <- function(x, ...) {
     submodel_lengths <- purrr::map(attr(x, "cols_map"), length)
     model_names <- names(attr(x, "cols_map"))
   } else if (mode == "classification") {
-    n_groups <- length(unique(dplyr::pull(attr(x, "train")[,.get_outcome(x)])))
+    n_groups <- length(unique(dplyr::pull(attr(x, "train")[, .get_outcome(x)])))
     n_cands <- (ncol(x) - 1) / n_groups
     n_model_defs <- length(attr(x, "model_defs"))
     outcome_name <- colnames(x)[1]
-    submodel_lengths <- 
+    submodel_lengths <-
       purrr::map_dbl(attr(x, "cols_map"), length) / n_groups
     model_names <- names(attr(x, "cols_map"))
   } else {
@@ -21,14 +21,18 @@ print.data_stack <- function(x, ...) {
     n_groups <- n_cands <- n_model_defs <- submodel_lengths <- 0
     outcome_name <- model_names <- NULL
   }
-  
-  cat(glue::glue("# A data stack with {n_model_defs} model definition",
-                 "{if (n_model_defs != 1) 's' else ''}",
-                 " and {n_cands} candidate member",
-                 "{if (n_cands != 1) 's' else ''}",
-                 "{if (n_model_defs != 0) ':' else '.'}"))
-  if (n_model_defs != 0) {cat("\n")}
-  
+
+  cat(glue::glue(
+    "# A data stack with {n_model_defs} model definition",
+    "{if (n_model_defs != 1) 's' else ''}",
+    " and {n_cands} candidate member",
+    "{if (n_cands != 1) 's' else ''}",
+    "{if (n_model_defs != 0) ':' else '.'}"
+  ))
+  if (n_model_defs != 0) {
+    cat("\n")
+  }
+
   n_by_model_defs <-
     purrr::map2(
       submodel_lengths,
@@ -37,74 +41,85 @@ print.data_stack <- function(x, ...) {
         cat(glue::glue(
           "#   {name}: ",
           "{submodels} model configuration",
-          "{if (submodels != 1) 's' else ''}")
-        )
+          "{if (submodels != 1) 's' else ''}"
+        ))
         cat("\n")
       }
     )
-  
+
   cat(glue::glue(
     "# Outcome: {if (.get_outcome(x) == 'init_') {NULL} else {.get_outcome(x)}}",
-    paste0(if (.get_outcome(x) != 'init_') { 
-      c(" (", class(dplyr::pull(x[,1])), ")")} else {NULL}, collapse = "")
+    paste0(
+      if (.get_outcome(x) != 'init_') {
+        c(" (", class(dplyr::pull(x[, 1])), ")")
+      } else {
+        NULL
+      },
+      collapse = ""
+    )
   ))
 }
 
 #' @export
 print.model_stack <- function(x, n = 10, ...) {
-  
-  rlang::inform(cli::rule("A stacked ensemble model", 
-                          width = min(65, cli::console_width())))
-  
+  cli::cli_text(cli::rule(
+    "A stacked ensemble model",
+    width = min(65, cli::console_width())
+  ))
+
   member_summary(x)
-  
+
   print_top_coefs(x)
-  
+
   if (is.null(x[["member_fits"]])) {
-    rlang::inform("\nMembers have not yet been fitted with `fit_members()`.")
+    cli::cli_text("\n")
+    cli::cli_text("Members have not yet been fitted with `fit_members()`.")
   }
-  
+
   invisible(NULL)
 }
 
 #' @export
 print.butchered_linear_stack <- function(x, ...) {
-  rlang::inform(cli::rule("A stacked ensemble model", 
-                          width = min(65, cli::console_width())))
-  
-  rlang::inform("\nPrint methods for butchered model stacks are disabled.")
+  cli::cli_text(cli::rule(
+    "A stacked ensemble model",
+    width = min(65, cli::console_width())
+  ))
+
+  cli::cli_text("\n")
+  cli::cli_text("Print methods for butchered model stacks are disabled.")
 }
 
 top_coefs <- function(x, penalty = x$penalty$penalty, n = 10) {
-  betas <- 
-    .get_glmn_coefs(x$coefs$fit, penalty = penalty) %>% 
+  betas <-
+    .get_glmn_coefs(x$coefs$fit, penalty = penalty) |>
     dplyr::filter(estimate != 0 & terms != "(Intercept)")
   n <- min(n, nrow(betas))
-  
+
   sub_models <-
-    purrr::map(x$cols_map, ~ tibble::tibble(terms = .x)) %>%
+    purrr::map(x$cols_map, function(.x) tibble::tibble(terms = .x)) |>
     purrr::list_rbind(names_to = "model_name")
-  model_types <- 
-    purrr::map(x$model_defs, workflows::extract_spec_parsnip) %>% 
-    purrr::map(~ tibble::tibble(model_type = class(.x)[1])) %>%
+  model_types <-
+    purrr::map(x$model_defs, workflows::extract_spec_parsnip) |>
+    purrr::map(function(.x) tibble::tibble(model_type = class(.x)[1])) |>
     purrr::list_rbind(names_to = "model_name")
-  res <- 
-    dplyr::left_join(betas, sub_models, by = "terms") %>% 
-    dplyr::left_join(model_types, by = "model_name") %>% 
-    dplyr::top_n(n, abs(estimate)) %>% 
+  res <-
+    dplyr::left_join(betas, sub_models, by = "terms") |>
+    dplyr::left_join(model_types, by = "model_name") |>
+    dplyr::top_n(n, abs(estimate)) |>
     dplyr::arrange(dplyr::desc(abs(estimate)))
-  
+
   if (any(names(res) == "class")) {
-    pred_levels <- 
-      x$train %>% 
-      dplyr::select(!!.get_outcome(x)) %>%
-      dplyr::pull() %>%
+    pred_levels <-
+      x$train |>
+      dplyr::select(!!.get_outcome(x)) |>
+      dplyr::pull() |>
       levels()
-    
+
     pred_strings <- paste0(".pred_", pred_levels, "_")
-    
+
     res <-
-      res %>%
+      res |>
       # possible code to split the pred class and (actual) member
       # dplyr::mutate(
       #   member_ = gsub(
@@ -118,35 +133,48 @@ top_coefs <- function(x, penalty = x$penalty$penalty, n = 10) {
       #     replacement = ""
       #   ),
       #   class = gsub(".pred_", x = class, rep = "")
-      # ) %>%
-      dplyr::mutate(class = factor(class, levels = pred_levels)) %>%
+      # ) |>
+      dplyr::mutate(class = factor(class, levels = pred_levels)) |>
       dplyr::select(member = terms, type = model_type, weight = estimate, class)
   } else {
-    res <- dplyr::select(res, member = terms, type = model_type, weight = estimate)
+    res <- dplyr::select(
+      res,
+      member = terms,
+      type = model_type,
+      weight = estimate
+    )
   }
-  
+
   res
 }
 
-print_top_coefs <- function(x, penalty = x$penalty$penalty, n = 10, digits = 3) {
+print_top_coefs <- function(
+  x,
+  penalty = x$penalty$penalty,
+  n = 10,
+  digits = 3
+) {
   res <- top_coefs(x, penalty = penalty, n = n)
-  
-  msg <- paste0("\nThe ", nrow(res), " highest weighted member",
-               if (x$mode == "regression") {"s"} else {" classes"},
-               " are:")
-  rlang::inform(msg)
+
+  cli::cli_text("\n")
+  values <- if (x$mode == "regression") {
+    "s"
+  } else {
+    " classes"
+  }
+  cli::cli_text("The {nrow(res)} highest weighted member{values} are:")
   print(res)
   invisible(NULL)
 }
 
 member_summary <- function(x, penalty = x$penalty$penalty) {
-  betas <- 
-    .get_glmn_coefs(x$coefs$fit, penalty = penalty) %>% 
+  betas <-
+    .get_glmn_coefs(x$coefs$fit, penalty = penalty) |>
     dplyr::filter(terms != "(Intercept)")
   all_terms <- length(unique(betas$terms))
   used_betas <- dplyr::filter(betas, estimate != 0)
   used_terms <- nrow(used_betas)
-  
+
   msg <- c(
     "",
     "Out of {all_terms} possible candidate members, the ensemble \\
@@ -158,14 +186,14 @@ member_summary <- function(x, penalty = x$penalty$penalty) {
   cli::cli_bullets(msg)
   if (any(names(betas) == "class")) {
     n_classes <- length(unique(betas$class))
-    beta_per_class <- 
-      used_betas %>% 
-      dplyr::group_by(class) %>% 
-      dplyr::count() %>% 
-      dplyr::ungroup() %>% 
-      dplyr::pull(n) %>% 
-      mean() %>% 
-      round(2) 
+    beta_per_class <-
+      used_betas |>
+      dplyr::group_by(class) |>
+      dplyr::count() |>
+      dplyr::ungroup() |>
+      dplyr::pull(n) |>
+      mean() |>
+      round(2)
     msg <- "Across the {n_classes} classes, there are an average \\
             of {beta_per_class} coefficients per class."
     cli::cli_bullets(msg)
