@@ -8,6 +8,7 @@ dplyr::`%>%`
 #' @importFrom cli cli_inform
 #' @importFrom cli cli_warn
 #' @importFrom cli cli_abort
+#' @importFrom cli qty
 #' @importFrom rlang caller_env %||%
 #' @import workflows
 
@@ -20,13 +21,14 @@ utils::globalVariables(c(
   ".metric",
   ".pred",
   ".pred_class",
+  ".sum",
   "across",
   "any_of",
   "as.formula",
   "assess_object",
   "coef",
   "contains",
-  "data", 
+  "data",
   "estimate",
   "estimate.x",
   "estimate.y",
@@ -69,31 +71,32 @@ check_empty_ellipses <- function(...) {
   dots <- rlang::enquos(...)
   if (length(dots) > 0) {
     needs_name <- names(dots) == ""
-    names(dots)[needs_name] <- 
-      dots[needs_name] %>%
+    names(dots)[needs_name] <-
+      dots[needs_name] |>
       purrr::map(
         rlang::get_expr
-      ) %>%
+      ) |>
       unlist()
-    
-    msg <- "The `...` are not used in this function but one or more arguments were passed: "
-    msg <- paste0(msg, paste0("'", names(dots), "'", collapse = ", "))
-    rlang::warn(msg)
+
+    cli_warn(
+      "The `...` are not used in this function but {?an/}
+       argument{?s} {.arg {names(dots)}} {?was/were} passed."
+    )
   }
   invisible(NULL)
 }
 
 check_inherits <- function(x, what, call = caller_env()) {
   cl <- match.call()
-  
+
   if (!inherits(x, what)) {
     cli_abort(
       "Element {.val {cl$x}} needs to inherit from {.var {what}}, but its 
-       class is {.var {class(x)}}.", 
+       class is {.var {class(x)}}.",
       call = call
     )
   }
-  
+
   invisible(TRUE)
 }
 
@@ -101,8 +104,7 @@ check_inherits <- function(x, what, call = caller_env()) {
 is_cran_check <- function() {
   if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     FALSE
-  }
-  else {
+  } else {
     Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
   }
 }
@@ -112,11 +114,11 @@ is_cran_check <- function() {
 # for use a la `@examplesIf (tune:::should_run_examples())`
 should_run_examples <- function(suggests = NULL) {
   has_needed_installs <- TRUE
-  
+
   if (!is.null(suggests)) {
     has_needed_installs <- rlang::is_installed(suggests)
   }
-  
+
   has_needed_installs && !is_cran_check()
 }
 
@@ -135,7 +137,9 @@ mode_is_regression <- function(x) {
   }
 }
 
-.get_rs_hash <- function(stack) {attr(stack, "rs_hash")}
+.get_rs_hash <- function(stack) {
+  attr(stack, "rs_hash")
+}
 
 .get_model_def_names <- function(stack) {
   if (!is.null(names(attr(stack, "model_defs")))) {
@@ -157,7 +161,10 @@ mode_is_regression <- function(x) {
   x <- x[, c("terms", "estimate", "penalty")]
 
   if (is.list(x$estimate)) {
-    x$estimate <- purrr::map(x$estimate, ~ tibble::as_tibble(as.matrix(.x), rownames = "terms"))
+    x$estimate <- purrr::map(
+      x$estimate,
+      function(.x) tibble::as_tibble(as.matrix(.x), rownames = "terms")
+    )
     x <- tidyr::unnest(x, cols = c(estimate), names_repair = "minimal")
     names(x) <- c("class", "terms", "estimate", "penalty")
   }
